# init.py
import os

def init() -> None:
    global FOLDER
    FOLDER = ""
    
    global SRC_DIR
    SRC_DIR = ""
    
    global APP_NAME
    APP_NAME = ""
    
    global APP_DIR
    APP_DIR = ""
    
    global GIT_REPO
    GIT_REPO = ""
    
    global CUSTOMER
    CUSTOMER = ""
    
    global ROOT_DIR
    ROOT_DIR = ""
    