from unittest import TestCase


class TestBaseField(TestCase):
    def test_create_dir(self):
        self.fail()

    def test_to_file(self):
        self.fail()

    def test_set_properties(self):
        self.fail()

    def test_create_validation_script(self):
        self.fail()
